@@ -216,9 +216,6 @@ class AuroraInitialConnectionStrategyPlugin(Plugin):
 
     def init_host_provider(self, props: Properties, host_list_provider_service: HostListProviderService, init_host_provider_func: Callable):
         self._host_list_provider_service = host_list_provider_service
-        if host_list_provider_service.is_static_host_list_provider():
-            raise AwsWrapperError(Messages.get("AuroraInitialConnectionStrategyPlugin.RequireDynamicProvider"))
-
         init_host_provider_func(props)
 
     def _has_no_readers(self) -> bool:
@@ -233,5 +230,6 @@ class AuroraInitialConnectionStrategyPlugin(Plugin):
 
 
 class AuroraInitialConnectionStrategyPluginFactory(PluginFactory):
-    def get_instance(self, plugin_service: PluginService, props: Properties) -> Plugin:
+    @staticmethod
+    def get_instance(plugin_service: PluginService, props: Properties) -> Plugin:
         return AuroraInitialConnectionStrategyPlugin(plugin_service)
