@@ -18,6 +18,8 @@ from typing import (TYPE_CHECKING, Callable, ClassVar, Dict, Optional,
                     Protocol, Tuple, runtime_checkable)
 
 from aws_advanced_python_wrapper.driver_info import DriverInfo
+from aws_advanced_python_wrapper.host_list_provider import (
+    AuroraTopologyUtils, MultiAzTopologyUtils)
 from aws_advanced_python_wrapper.utils.rds_url_type import RdsUrlType
 
 if TYPE_CHECKING:
@@ -26,16 +28,17 @@ if TYPE_CHECKING:
     from .exception_handling import ExceptionHandler
 
 from abc import ABC, abstractmethod
-from concurrent.futures import Executor, ThreadPoolExecutor, TimeoutError
+from concurrent.futures import TimeoutError
 from contextlib import closing
 from enum import Enum, auto
 
 from aws_advanced_python_wrapper.errors import (AwsWrapperError,
                                                 QueryTimeoutError)
 from aws_advanced_python_wrapper.host_list_provider import (
-    ConnectionStringHostListProvider, MultiAzHostListProvider,
-    RdsHostListProvider)
+    ConnectionStringHostListProvider, RdsHostListProvider)
 from aws_advanced_python_wrapper.hostinfo import HostInfo
+from aws_advanced_python_wrapper.thread_pool_container import \
+    ThreadPoolContainer
 from aws_advanced_python_wrapper.utils.decorators import \
     preserve_transaction_status_with_timeout
 from aws_advanced_python_wrapper.utils.log import Logger
@@ -177,7 +180,7 @@ class MysqlDatabaseDialect(DatabaseDialect):
 
     @property
     def host_alias_query(self) -> str:
-        return "SELECT pg_catalog.CONCAT(@@hostname, ':', @@port)"
+        return "SELECT CONCAT(@@hostname, ':', @@port)"
 
     @property
     def server_version_query(self) -> str:
@@ -408,7 +411,7 @@ class AuroraMysqlDialect(MysqlDatabaseDialect, TopologyAwareDatabaseDialect, Blu
         return False
 
     def get_host_list_provider_supplier(self) -> Callable:
-        return lambda provider_service, props: RdsHostListProvider(provider_service, props)
+        return lambda provider_service, props: RdsHostListProvider(provider_service, props, AuroraTopologyUtils(self, props))
 
     @property
     def blue_green_status_query(self) -> str:
@@ -481,7 +484,7 @@ class AuroraPgDialect(PgDatabaseDialect, TopologyAwareDatabaseDialect, AuroraLim
         return False
 
     def get_host_list_provider_supplier(self) -> Callable:
-        return lambda provider_service, props: RdsHostListProvider(provider_service, props)
+        return lambda provider_service, props: RdsHostListProvider(provider_service, props, AuroraTopologyUtils(self, props))
 
     @property
     def blue_green_status_query(self) -> str:
@@ -531,14 +534,10 @@ class MultiAzClusterMysqlDialect(MysqlDatabaseDialect, TopologyAwareDatabaseDial
         return False
 
     def get_host_list_provider_supplier(self) -> Callable:
-        return lambda provider_service, props: MultiAzHostListProvider(
+        return lambda provider_service, props: RdsHostListProvider(
             provider_service,
             props,
-            self._TOPOLOGY_QUERY,
-            self._HOST_ID_QUERY,
-            self._IS_READER_QUERY,
-            self._WRITER_HOST_QUERY,
-            self._WRITER_HOST_COLUMN_INDEX)
+            MultiAzTopologyUtils(self, props, self._WRITER_HOST_QUERY, self._WRITER_HOST_COLUMN_INDEX))
 
     def prepare_conn_props(self, props: Properties):
         # These props are added for RDS metrics purposes, they are not required for functional correctness.
@@ -590,13 +589,10 @@ class MultiAzClusterPgDialect(PgDatabaseDialect, TopologyAwareDatabaseDialect):
         return False
 
     def get_host_list_provider_supplier(self) -> Callable:
-        return lambda provider_service, props: MultiAzHostListProvider(
+        return lambda provider_service, props: RdsHostListProvider(
             provider_service,
             props,
-            self._TOPOLOGY_QUERY,
-            self._HOST_ID_QUERY,
-            self._IS_READER_QUERY,
-            self._WRITER_HOST_QUERY)
+            MultiAzTopologyUtils(self, props, self._WRITER_HOST_QUERY))
 
 
 class UnknownDatabaseDialect(DatabaseDialect):
@@ -644,7 +640,7 @@ class DatabaseDialectManager(DatabaseDialectProvider):
     _ENDPOINT_CACHE_EXPIRATION_NS = 30 * 60_000_000_000  # 30 minutes
     _known_endpoint_dialects: CacheMap[str, DialectCode] = CacheMap()
     _custom_dialect: Optional[DatabaseDialect] = None
-    _executor: ClassVar[Executor] = ThreadPoolExecutor(thread_name_prefix="DatabaseDialectManagerExecutor")
+    _executor_name: ClassVar[str] = "DatabaseDialectManagerExecutor"
     _known_dialects_by_code: Dict[DialectCode, DatabaseDialect] = {
         DialectCode.MYSQL: MysqlDatabaseDialect(),
         DialectCode.RDS_MYSQL: RdsMysqlDialect(),
@@ -782,7 +778,7 @@ class DatabaseDialectManager(DatabaseDialectProvider):
                 timeout_sec = WrapperProperties.AUXILIARY_QUERY_TIMEOUT_SEC.get(self._props)
                 try:
                     cursor_execute_func_with_timeout = preserve_transaction_status_with_timeout(
-                        DatabaseDialectManager._executor,
+                        ThreadPoolContainer.get_thread_pool(DatabaseDialectManager._executor_name),
                         timeout_sec,
                         driver_dialect,
                         conn)(dialect_candidate.is_dialect)
