@@ -22,27 +22,29 @@ if TYPE_CHECKING:
     from aws_advanced_python_wrapper.pep249 import Connection
     from aws_advanced_python_wrapper.plugin_service import PluginService
 
-from concurrent.futures import (Executor, Future, ThreadPoolExecutor,
-                                TimeoutError)
-from copy import copy
+from concurrent.futures import Future, TimeoutError
 from dataclasses import dataclass
 from queue import Queue
 from threading import Event, Lock, RLock
-from time import perf_counter_ns, sleep
+from time import perf_counter_ns
 from typing import Any, Callable, ClassVar, Dict, FrozenSet, Optional, Set
 
 from _weakref import ReferenceType, ref
 
 from aws_advanced_python_wrapper.errors import AwsWrapperError
 from aws_advanced_python_wrapper.host_availability import HostAvailability
+from aws_advanced_python_wrapper.pep249_methods import DbApiMethod
 from aws_advanced_python_wrapper.plugin import (CanReleaseResources, Plugin,
                                                 PluginFactory)
+from aws_advanced_python_wrapper.thread_pool_container import \
+    ThreadPoolContainer
 from aws_advanced_python_wrapper.utils.concurrent import ConcurrentDict
 from aws_advanced_python_wrapper.utils.log import Logger
 from aws_advanced_python_wrapper.utils.messages import Messages
 from aws_advanced_python_wrapper.utils.notifications import (
     ConnectionEvent, HostEvent, OldConnectionSuggestedAction)
 from aws_advanced_python_wrapper.utils.properties import (Properties,
+                                                          PropertiesUtils,
                                                           WrapperProperties)
 from aws_advanced_python_wrapper.utils.rdsutils import RdsUtils
 from aws_advanced_python_wrapper.utils.telemetry.telemetry import (
@@ -53,12 +55,17 @@ logger = Logger(__name__)
 
 
 class HostMonitoringPluginFactory(PluginFactory):
-    def get_instance(self, plugin_service: PluginService, props: Properties) -> Plugin:
+    @staticmethod
+    def get_instance(plugin_service: PluginService, props: Properties) -> Plugin:
         return HostMonitoringPlugin(plugin_service, props)
 
 
 class HostMonitoringPlugin(Plugin, CanReleaseResources):
-    _SUBSCRIBED_METHODS: Set[str] = {"*"}
+    _SUBSCRIBED_METHODS: Set[str] = {
+        DbApiMethod.CONNECT.method_name,
+        DbApiMethod.NOTIFY_HOST_LIST_CHANGED.method_name,
+        DbApiMethod.NOTIFY_CONNECTION_CHANGED.method_name
+    }
 
     def __init__(self, plugin_service, props):
         dialect: DriverDialect = plugin_service.driver_dialect
@@ -73,6 +80,11 @@ class HostMonitoringPlugin(Plugin, CanReleaseResources):
         self._rds_utils: RdsUtils = RdsUtils()
         self._monitor_service: MonitorService = MonitorService(plugin_service)
         self._lock: Lock = Lock()
+        self._is_enabled = WrapperProperties.FAILURE_DETECTION_ENABLED.get_bool(self._props)
+        self._failure_detection_time_ms = WrapperProperties.FAILURE_DETECTION_TIME_MS.get_int(self._props)
+        self._failure_detection_interval = WrapperProperties.FAILURE_DETECTION_INTERVAL_MS.get_int(self._props)
+        self._failure_detection_count = WrapperProperties.FAILURE_DETECTION_COUNT.get_int(self._props)
+        HostMonitoringPlugin._SUBSCRIBED_METHODS.update(self._plugin_service.network_bound_methods)
 
     @property
     def subscribed_methods(self) -> Set[str]:
@@ -103,14 +115,9 @@ class HostMonitoringPlugin(Plugin, CanReleaseResources):
         if host_info is None:
             raise AwsWrapperError(Messages.get_formatted("HostMonitoringPlugin.HostInfoNoneForMethod", method_name))
 
-        is_enabled = WrapperProperties.FAILURE_DETECTION_ENABLED.get_bool(self._props)
-        if not is_enabled or not self._plugin_service.is_network_bound_method(method_name):
+        if not self._is_enabled or not self._plugin_service.is_network_bound_method(method_name):
             return execute_func()
 
-        failure_detection_time_ms = WrapperProperties.FAILURE_DETECTION_TIME_MS.get_int(self._props)
-        failure_detection_interval = WrapperProperties.FAILURE_DETECTION_INTERVAL_MS.get_int(self._props)
-        failure_detection_count = WrapperProperties.FAILURE_DETECTION_COUNT.get_int(self._props)
-
         monitor_context = None
         result = None
 
@@ -121,9 +128,9 @@ class HostMonitoringPlugin(Plugin, CanReleaseResources):
                 self._get_monitoring_host_info().all_aliases,
                 self._get_monitoring_host_info(),
                 self._props,
-                failure_detection_time_ms,
-                failure_detection_interval,
-                failure_detection_count
+                self._failure_detection_time_ms,
+                self._failure_detection_interval,
+                self._failure_detection_count
             )
             result = execute_func()
         finally:
@@ -214,7 +221,7 @@ class MonitoringContext:
             failure_detection_time_ms: int,
             failure_detection_interval_ms: int,
             failure_detection_count: int,
-            aborted_connections_counter: TelemetryCounter):
+            aborted_connections_counter: TelemetryCounter | None):
         self._monitor: Monitor = monitor
         self._connection: Connection = connection
         self._target_dialect: DriverDialect = target_dialect
@@ -320,7 +327,8 @@ class MonitoringContext:
             logger.debug("MonitorContext.HostUnavailable", host)
             self._is_host_unavailable = True
             self._abort_connection()
-            self._aborted_connections_counter.inc()
+            if self._aborted_connections_counter is not None:
+                self._aborted_connections_counter.inc()
             return
 
         logger.debug("MonitorContext.HostNotResponding", host, self._current_failure_count)
@@ -335,7 +343,6 @@ class Monitor:
     _DEFAULT_CONNECT_TIMEOUT_SEC = 10
     _INACTIVE_SLEEP_MS = 100
     _MIN_HOST_CHECK_TIMEOUT_MS = 3000
-    _MONITORING_PROPERTY_PREFIX = "monitoring-"
     _QUERY = "SELECT 1"
 
     def __init__(
@@ -505,38 +512,39 @@ class Monitor:
     def _check_host_status(self, host_check_timeout_ms: int) -> HostStatus:
         context = self._telemetry_factory.open_telemetry_context(
             "connection status check", TelemetryTraceLevel.FORCE_TOP_LEVEL)
-        context.set_attribute("url", self._host_info.url)
+
+        if context is not None:
+            context.set_attribute("url", self._host_info.url)
 
         start_ns = perf_counter_ns()
         try:
             driver_dialect = self._plugin_service.driver_dialect
             if self._monitoring_conn is None or driver_dialect.is_closed(self._monitoring_conn):
-                props_copy: Properties = copy(self._props)
-                for key, value in self._props.items():
-                    if key.startswith(Monitor._MONITORING_PROPERTY_PREFIX):
-                        props_copy[key[len(Monitor._MONITORING_PROPERTY_PREFIX):len(key)]] = value
-                        props_copy.pop(key, None)
+                monitoring_properties: Properties = PropertiesUtils.create_monitoring_properties(self._props)
 
                 # Set a default connect timeout if the user hasn't configured one
-                if props_copy.get(WrapperProperties.CONNECT_TIMEOUT_SEC.name, None) is None:
-                    props_copy[WrapperProperties.CONNECT_TIMEOUT_SEC.name] = Monitor._DEFAULT_CONNECT_TIMEOUT_SEC
+                if monitoring_properties.get(WrapperProperties.CONNECT_TIMEOUT_SEC.name, None) is None:
+                    monitoring_properties[WrapperProperties.CONNECT_TIMEOUT_SEC.name] = Monitor._DEFAULT_CONNECT_TIMEOUT_SEC
 
                 logger.debug("Monitor.OpeningMonitorConnection", self._host_info.url)
                 start_ns = perf_counter_ns()
-                self._monitoring_conn = self._plugin_service.force_connect(self._host_info, props_copy, None)
+                self._monitoring_conn = self._plugin_service.force_connect(self._host_info, monitoring_properties, None)
                 logger.debug("Monitor.OpenedMonitorConnection", self._host_info.url)
                 return Monitor.HostStatus(True, perf_counter_ns() - start_ns)
 
             start_ns = perf_counter_ns()
             is_available = self._is_host_available(self._monitoring_conn, host_check_timeout_ms / 1000)
             if not is_available:
-                self._host_invalid_counter.inc()
+                if self._host_invalid_counter is not None:
+                    self._host_invalid_counter.inc()
             return Monitor.HostStatus(is_available, perf_counter_ns() - start_ns)
         except Exception:
-            self._host_invalid_counter.inc()
+            if self._host_invalid_counter is not None:
+                self._host_invalid_counter.inc()
             return Monitor.HostStatus(False, perf_counter_ns() - start_ns)
         finally:
-            context.close_context()
+            if context is not None:
+                context.close_context()
 
     def _is_host_available(self, conn: Connection, timeout_sec: float) -> bool:
         try:
@@ -549,12 +557,11 @@ class Monitor:
         driver_dialect = self._plugin_service.driver_dialect
         with conn.cursor() as cursor:
             query = Monitor._QUERY
-            driver_dialect.execute("Cursor.execute", lambda: cursor.execute(query), query, exec_timeout=timeout_sec)
+            driver_dialect.execute(DbApiMethod.CURSOR_EXECUTE.method_name, lambda: cursor.execute(query), query, exec_timeout=timeout_sec)
             cursor.fetchone()
 
-    # Used to help with testing
     def sleep(self, duration: int):
-        sleep(duration)
+        self._is_stopped.wait(duration)
 
 
 class MonitoringThreadContainer:
@@ -569,7 +576,7 @@ class MonitoringThreadContainer:
 
     _monitor_map: ConcurrentDict[str, Monitor] = ConcurrentDict()
     _tasks_map: ConcurrentDict[Monitor, Future] = ConcurrentDict()
-    _executor: ClassVar[Executor] = ThreadPoolExecutor(thread_name_prefix="MonitoringThreadContainerExecutor")
+    _executor_name: ClassVar[str] = "MonitoringThreadContainerExecutor"
 
     # This logic ensures that this class is a Singleton
     def __new__(cls, *args, **kwargs):
@@ -597,7 +604,9 @@ class MonitoringThreadContainer:
                 if supplied_monitor is None:
                     raise AwsWrapperError(Messages.get("MonitoringThreadContainer.SupplierMonitorNone"))
                 self._tasks_map.compute_if_absent(
-                    supplied_monitor, lambda _: MonitoringThreadContainer._executor.submit(supplied_monitor.run))
+                    supplied_monitor,
+                    lambda _: ThreadPoolContainer.get_thread_pool(MonitoringThreadContainer._executor_name)
+                    .submit(supplied_monitor.run))
                 return supplied_monitor
 
             if monitor is None:
@@ -652,12 +661,9 @@ class MonitoringThreadContainer:
             for monitor, _ in self._tasks_map.items():
                 monitor.stop()
 
+            ThreadPoolContainer.release_pool(MonitoringThreadContainer._executor_name, wait=False)
             self._tasks_map.clear()
 
-            # Reset the executor.
-            self._executor.shutdown(wait=False)
-            MonitoringThreadContainer._executor = ThreadPoolExecutor(thread_name_prefix="MonitoringThreadContainerExecutor")
-
 
 class MonitorService:
     def __init__(self, plugin_service: PluginService):
