@@ -17,6 +17,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from aws_advanced_python_wrapper.utils.iam_utils import IamAuthUtils, TokenInfo
+from aws_advanced_python_wrapper.utils.region_utils import RegionUtils
 
 if TYPE_CHECKING:
     from boto3 import Session
@@ -29,6 +30,7 @@ from datetime import datetime, timedelta
 from typing import Callable, Dict, Optional, Set
 
 from aws_advanced_python_wrapper.errors import AwsWrapperError
+from aws_advanced_python_wrapper.pep249_methods import DbApiMethod
 from aws_advanced_python_wrapper.plugin import Plugin, PluginFactory
 from aws_advanced_python_wrapper.utils.log import Logger
 from aws_advanced_python_wrapper.utils.messages import Messages
@@ -40,7 +42,7 @@ logger = Logger(__name__)
 
 
 class IamAuthPlugin(Plugin):
-    _SUBSCRIBED_METHODS: Set[str] = {"connect", "force_connect"}
+    _SUBSCRIBED_METHODS: Set[str] = {DbApiMethod.CONNECT.method_name, DbApiMethod.FORCE_CONNECT.method_name}
     # Leave 30 second buffer to prevent time-of-check to time-of-use errors
     _DEFAULT_TOKEN_EXPIRATION_SEC = 15 * 60 - 30
 
@@ -51,6 +53,7 @@ class IamAuthPlugin(Plugin):
         self._plugin_service = plugin_service
         self._session = session
 
+        self._region_utils = RegionUtils()
         telemetry_factory = self._plugin_service.get_telemetry_factory()
         self._fetch_token_counter = telemetry_factory.create_counter("iam.fetch_token.count")
         self._cache_size_gauge = telemetry_factory.create_gauge(
@@ -76,8 +79,12 @@ class IamAuthPlugin(Plugin):
             raise AwsWrapperError(Messages.get_formatted("IamAuthPlugin.IsNoneOrEmpty", WrapperProperties.USER.name))
 
         host = IamAuthUtils.get_iam_host(props, host_info)
-        region = WrapperProperties.IAM_REGION.get(props) \
-            if WrapperProperties.IAM_REGION.get(props) else IamAuthUtils.get_rds_region(self._rds_utils, host, props, self._session)
+        region = self._region_utils.get_region(props, WrapperProperties.IAM_REGION.name, host)
+        if not region:
+            error_message = "RdsUtils.UnsupportedHostname"
+            logger.debug(error_message, host)
+            raise AwsWrapperError(Messages.get_formatted(error_message, host))
+
         port = IamAuthUtils.get_port(props, host_info, self._plugin_service.database_dialect.default_port)
         token_expiration_sec: int = WrapperProperties.IAM_EXPIRATION.get_int(props)
 
@@ -95,7 +102,8 @@ class IamAuthPlugin(Plugin):
             self._plugin_service.driver_dialect.set_password(props, token_info.token)
         else:
             token_expiry = datetime.now() + timedelta(seconds=token_expiration_sec)
-            self._fetch_token_counter.inc()
+            if self._fetch_token_counter is not None:
+                self._fetch_token_counter.inc()
             token: str = IamAuthUtils.generate_authentication_token(self._plugin_service, user, host, port, region, client_session=self._session)
             self._plugin_service.driver_dialect.set_password(props, token)
             IamAuthPlugin._token_cache[cache_key] = TokenInfo(token, token_expiry)
@@ -113,7 +121,8 @@ class IamAuthPlugin(Plugin):
             # Login unsuccessful with cached token
             # Try to generate a new token and try to connect again
             token_expiry = datetime.now() + timedelta(seconds=token_expiration_sec)
-            self._fetch_token_counter.inc()
+            if self._fetch_token_counter is not None:
+                self._fetch_token_counter.inc()
             token = IamAuthUtils.generate_authentication_token(self._plugin_service, user, host, port, region, client_session=self._session)
             self._plugin_service.driver_dialect.set_password(props, token)
             IamAuthPlugin._token_cache[cache_key] = TokenInfo(token, token_expiry)
@@ -135,5 +144,6 @@ class IamAuthPlugin(Plugin):
 
 
 class IamAuthPluginFactory(PluginFactory):
-    def get_instance(self, plugin_service: PluginService, props: Properties) -> Plugin:
+    @staticmethod
+    def get_instance(plugin_service: PluginService, props: Properties) -> Plugin:
         return IamAuthPlugin(plugin_service)
